==> haskell-text-metrics-0.3.3-43.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-metrics
version:              0.3.3
visibility:           public
id:                   text-metrics-0.3.3-EtdayY9JRqPIHrPm1Benmg
key:                  text-metrics-0.3.3-EtdayY9JRqPIHrPm1Benmg
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/text-metrics
synopsis:             Calculate various string metrics efficiently
description:          Calculate various string metrics efficiently.
category:             Text, Algorithms
abi:                  240939073a361ec892bf4fd94b15a883
exposed:              True
exposed-modules:      Data.Text.Metrics
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-metrics-0.3.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-metrics-0.3.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-metrics-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-metrics
hs-libraries:         HStext-metrics-0.3.3-EtdayY9JRqPIHrPm1Benmg
depends:
    base-4.18.2.1 containers-0.6.7
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ text-2.0.2
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock

haddock-html:         /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-metrics-0.3.3-44-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-text-metrics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-metrics
version:              0.3.3
visibility:           public
id:                   text-metrics-0.3.3-542FvMYuyImLLT35eUtKmy
key:                  text-metrics-0.3.3-542FvMYuyImLLT35eUtKmy
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/text-metrics
synopsis:             Calculate various string metrics efficiently
description:          Calculate various string metrics efficiently.
category:             Text, Algorithms
abi:                  59bca22c8c264b65262df351c12172a2
exposed:              True
exposed-modules:      Data.Text.Metrics
import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-metrics-0.3.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-metrics-0.3.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-metrics-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-metrics
hs-libraries:         HStext-metrics-0.3.3-542FvMYuyImLLT35eUtKmy
depends:
    base-4.18.2.1 containers-0.6.7
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi text-2.0.2
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-text-metrics/html/text-metrics.haddock

haddock-html:         /usr/share/doc/haskell-text-metrics/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
